# TI Nspire Serial Adapter

Original author: Daniel Tang (tangrs@tangrs.id.au).

Released: 2022-03-19

## Background

I've received numerous emails asking for the design files for my TI Nspire
serial adapter design from 2014, ever since I stopped selling them. The design
is pretty crude, so I'm not quite sure how useful they are, but here they are
anyway.

Please also note that this is by no means a polished design. The design files
date back to when I first started learning building PCBs and 3D modeling. The
state of these design files definitely do not reflect how I'd have approached
the project if I were to do it again today :)

## Caveats

Since I no longer produce those, and I don't really work on the TI Nspire any
more, I won't be providing any support or guidance beyond the notes in this
README. These notes are intended for a hobbyist who is comfortable with:

* Working with basic PCB designs.
* Working with basic 3D printing + modeling.
* Working with a heat gun/soldering iron.

These notes were also written from memory (I didn't document much at the time).

These were also fabulously expensive to produce in small quantities. At the
time, the surface mount contacts were difficult to source in low MOQs. I'm also
unsure how expensive PCB manufacturing is today, compared to back then. Your
mileage may vary.

## Bill of Materials

* 1206 capacitor, 100nF (populates C4, C5, C6)
* FT232RL IC, USB TO UART, SMD, 28SSOP
* MUSB-05-S-B-SM-A
* 120220-0206 CONTACT, UNIVERSAL, 4MM

## Assembling the PCB

No schematics are available, because the PCB was essentially drawn manually.
However, it's basically a stripped-down version of a FT232RL reference design.
It's not too difficult to reverse engineer if you really need a schematic.

See `prototype.jpg` in the images folder for what a populated board looks. Note
that the contact pins shown in that picture are different vs the final design.

I recommend soldering the surface-mount contacts first. These can be difficult
to solder by hand. My method was to stick the contact on the correct pads using
solder paste, then heating the board from underneath (rather than using hot
air). This should cause the pins to self-align as the solder melts. If done
correctly, there should be no solder bridges/shorts across the pins. If not,
try again using less solder paste.

The other components are relatively straightforward to solder with an iron. My
method of choice was reflow soldering however.

## Assembling the dock

The source files are in the OpenSCAD format. The STL file is tuned for the
tolerances of my particular 3D printer - some adjustments may be necessary for
your 3D printer. Unfortunately, the source files aren't written in a
particularly maintainable fashion.

The dock was designed to be printed in the upwards orientation to avoid
overhang. It does require good print-bed adhesion, and careful attention to
nozzle temperature when it prints the arms that go into the calculator.

The adapter is assembled by slotting the assembled PCB into the tray. It should
be a snug fit and shouldn't require any adhesive to keep the PCB in place. See
included images for how it's supposed to come together.

## Potential improvements

Some things I'd do differently if I were to tackle this project again today:

* USB-C connector (or at least Micro-B).
  * Alternatively, provide no USB serial at all, and simply expose the pins in
    the form of an ordinary 2.54mm pin header. Chances are, the user already
    has a 3.3v USB-serial adapter already.
* Make the PCB more compact. There's so much unnecessary dead space.

## Licence

This work is licensed under a [Creative Commons Attribution 4.0 International
License](http://creativecommons.org/licenses/by/4.0/).

The images, gerbers and dock design files are all covered under this license.