// This work is licensed under a Creative Commons Attribution 4.0 International License.

include <config.scad>

module usb_cutout(h) {
  scale(v=[1.08, 1, 1.08])
  rotate(a=[90,0,0])
  linear_extrude(height=h, center=true)
    polygon(points=[[0.7, 0], [0, 2], [0, 4], [7.7, 4], [7.7, 2], [7, 0]], paths=[[0, 1, 2, 3, 4, 5]]);
}

module tongue() {
  corner_radius = 0.7;
  size = [42.5, tongue_length, 5];

  translate(v=[-0.5*size[0], 0])
  union() {
    cube(size=size - [0, 0, corner_radius]);

    translate(v=[corner_radius, 0, size[2] - corner_radius])
    cube(size=[size[0] - 2*corner_radius, size[1], corner_radius]);

    translate(v=[corner_radius, 0, size[2] - corner_radius])
    rotate(a=[-90, 0, 0])
    cylinder(r=corner_radius, h=tongue_length, $fn=24);

    translate(v=[size[0] - corner_radius, 0, size[2] - corner_radius])
    rotate(a=[-90, 0, 0])
    cylinder(r=corner_radius, h=tongue_length, $fn=24);
  }
}

module round_cut(r, h) {
  l = sqrt(2 * r * r);
  difference() {
    rotate(a=[0, 0, -45])
    cube(size=[l, l, h]);
  }
}

module bottom() {
  difference() {
    cube(size=bottom_dimensions);

    translate(v=[wall_width + calculator_bottom_radius, bottom_height + calculator_bottom_radius])
    cylinder(r=calculator_bottom_radius, h=bottom_dimensions[2]);

    translate(v=[bottom_dimensions[0] - wall_width - calculator_bottom_radius, bottom_height + calculator_bottom_radius])
    cylinder(r=calculator_bottom_radius, h=bottom_dimensions[2]);

    translate(v=[wall_width + calculator_bottom_radius, bottom_height])
    cube(size=[bottom_dimensions[0] - 2*wall_width - 2*calculator_bottom_radius, calculator_bottom_radius, bottom_dimensions[2]]);

    translate(v=[wall_width, bottom_height + calculator_bottom_radius - 1])
    cube(size=[bottom_dimensions[0] - 2*wall_width, bottom_dimensions[1], bottom_dimensions[2]]);
  }
}


module strip(length) {
  size = [1.7, length, 1.4];

  cube(size=size);
}

module case() {
  radius = 20;

  difference() {
    union() {
      bottom();

      translate(v=[0.5*bottom_dimensions[0], bottom_height])
      tongue(tongue_length);

      translate(v=[wall_width, 0, strip_bottom_offset])
      strip(bottom_dimensions[1]);

      translate(v=[bottom_dimensions[0] - wall_width, 0, strip_bottom_offset])
      mirror(v=[1,0,0])
      strip(bottom_dimensions[1]);
    }

    translate(v=[0.5*bottom_dimensions[0] - 0.5*pcb_dimensions[0], pcb_wall_width, 5 - pcb_bottom_clearance]) {
      cube(size=pcb_dimensions + [0,0, -pcb_dimensions[2] + pcb_height_clearance]);

      translate(v=[usb_h_offset, 0, pcb_dimensions[2]])
      usb_cutout(5);
    }

    translate(v=[bottom_dimensions[0] - radius, 0, 0])
    round_cut(r=radius, h=bottom_dimensions[2]);

    translate(v=[radius,0])
    mirror(v=[1,0,0])
    round_cut(r=radius, h=bottom_dimensions[2]);

    translate(v=[0.5*bottom_dimensions[0], pcb_dimensions[1] + wall_width, 4.5])
    cube(size=[2.5, 8, 5], center=true);
  }
}

//round_cut(10, 10);

//rotate(a=[90,0,0])
$fn=100;
case();